==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/items/menu/LanguageMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.language.ChangeLanguageAction;
import org.herac.tuxguitar.gui.items.ItemContainer;
import org.herac.tuxguitar.gui.language.LanguageManager;

/**
 * @author julian
 * 
 * TODO To change the template for this generated type comment go to Window - Preferences - Java - Code Style - Code Templates
 */
public class LanguageMenuItem implements ItemContainer {
    private LanguageManager languageManager;
    private MenuItem languageMenuItem;
    private Menu menu;
    private MenuItem[] languages;
    
    public LanguageMenuItem(Shell shell,Menu parent, int style) {
        this.languageMenuItem = new MenuItem(parent, style);
        this.menu = new Menu(shell, SWT.DROP_DOWN);
    }

    
    public void showItems(){  
        this.languageManager = TuxGuitar.instance().getLanguageManager();
        String[] languages = this.languageManager.getLanguages();
        if(languages != null){
        
        	this.languages = new MenuItem[languages.length];
        	for(int i = 0;i < languages.length;i++){
        		this.languages[i] =  new MenuItem(this.menu, SWT.CHECK);
        		this.languages[i].setData(languages[i]);
        		this.languages[i].addSelectionListener(TuxGuitar.instance().getAction(ChangeLanguageAction.NAME));
        		this.languages[i].setText(languages[i]);
        	}
        	this.languageMenuItem.setMenu(menu);        
        	this.update();        
        }        
        this.loadProperties();
    }

    
    public void update(){
    	if(this.languages != null){    	
    		String language = this.languageManager.getLanguage();
    		for(int i = 0;i < this.languages.length;i++){
    			Object data = this.languages[i].getData();
    			if(data instanceof String){
    				this.languages[i].setSelection(data.toString().equals(language));
    			}
    		}   
    	}
    }
    
    public void loadProperties(){
        this.languageMenuItem.setText(TuxGuitar.getProperty("language"));  
        if(this.languages != null){    	
        	for(int i = 0;i < this.languages.length;i++){
            	Object data = this.languages[i].getData();
            	if(data instanceof String){
                	this.languages[i].setText(TuxGuitar.getProperty(data.toString()));
            	}
        	}    
        }
    }         
}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/items/menu/LanguageMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
/*
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.language.ChangeLanguageAction;
import org.herac.tuxguitar.gui.items.MenuItems;
import org.herac.tuxguitar.gui.system.language.LanguageManager;

/**
 * @author julian
 * 
 * TODO To change the template for this generated type comment go to Window - Preferences - Java - Code Style - Code Templates
 *//*
public class LanguageMenuItem implements MenuItems {
    private LanguageManager languageManager;
    private MenuItem languageMenuItem;
    private Menu menu;
    private MenuItem[] languages;
    
    public LanguageMenuItem(Shell shell,Menu parent, int style) {
        this.languageMenuItem = new MenuItem(parent, style);
        this.menu = new Menu(shell, SWT.DROP_DOWN);
    }

    
    public void showItems(){  
        this.languageManager = TuxGuitar.instance().getLanguageManager();
        String[] languages = this.languageManager.getLanguages();
        if(languages != null){
        
        	this.languages = new MenuItem[languages.length];
        	for(int i = 0;i < languages.length;i++){
        		this.languages[i] =  new MenuItem(this.menu, SWT.CHECK);
        		this.languages[i].setData(languages[i]);
        		this.languages[i].addSelectionListener(TuxGuitar.instance().getAction(ChangeLanguageAction.NAME));
        		this.languages[i].setText(languages[i]);
        	}
        	this.languageMenuItem.setMenu(menu);        
        	this.update();        
        }        
        this.loadProperties();
    }

    
    public void update(){
    	if(this.languages != null){    	
    		String language = this.languageManager.getLanguage();
    		for(int i = 0;i < this.languages.length;i++){
    			Object data = this.languages[i].getData();
    			if(data instanceof String){
    				this.languages[i].setSelection(data.toString().equals(language));
    			}
    		}   
    	}
    }
    
    public void loadProperties(){
        this.languageMenuItem.setText(TuxGuitar.getProperty("language"));  
        if(this.languages != null){    	
        	for(int i = 0;i < this.languages.length;i++){
            	Object data = this.languages[i].getData();
            	if(data instanceof String){
                	this.languages[i].setText(TuxGuitar.getProperty(data.toString()));
            	}
        	}    
        }
    }         
}*/
